@@ -51,6 +51,10 @@ public:
     KPublicTransport::Stopover departure(const QString &resId) const;
     KPublicTransport::JourneySection journey(const QString &resId) const;
 
+    [[nodiscard]] KPublicTransport::JourneySection trip(const QString &resId) const;
+    [[nodiscard]] qsizetype tripDepartureIndex(const QString &resId) const;
+    [[nodiscard]] qsizetype tripArrivalIndex(const QString &resId) const;
+
     /** Sets journey data for a given reservation, overwriting all existing data
      *  and not triggering notifications.
      *  Used to retain live data from alternative journey selections for example.
@@ -79,8 +83,6 @@ public:
     Q_INVOKABLE void checkForUpdates(const QStringList &batchIds);
 
 Q_SIGNALS:
-    void arrivalUpdated(const QString &resId);
-    void departureUpdated(const QString &resId);
     void journeyUpdated(const QString &resId);
 
 private:
@@ -94,8 +96,6 @@ private:
     void checkReservation(const QVariant &res, const QString &resId);
     void tripQueryFailed(const QString &resId);
 
-    void updateJourneyData(const KPublicTransport::JourneySection &journey, const QString &resId, const QVariant &res);
-
     void showNotification(const QString &resId, const LiveData &ld);
     void fillNotification(KNotification *n, const LiveData &ld) const;
     void cancelNotification(const QString &resId);
@@ -123,7 +123,7 @@ private:
     int pollCooldown(const QString &redId) const;
 
     /** Last time we queried any kind of departure information for this reservation batch. */
-    QDateTime lastDeparturePollTime(const QString &batchId, const QVariant &res) const;
+    [[nodiscard]] QDateTime lastPollTime(const QString &batchId, const QVariant &res) const;
 
     /** Notifications handling for pkpass updates. */
     void pkPassUpdated(const QString &passId, const QStringList &changes);
