@@ -27,6 +27,7 @@
 #include "locationinformation.h"
 #include "mapdownloadmanager.h"
 #include "matrixcontroller.h"
+#include "migrator.h"
 #include "navigationcontroller.h"
 #include "notificationconfigcontroller.h"
 #include "onlineticketimporter.h"
@@ -53,7 +54,6 @@
 #include "tripgroupmanager.h"
 #include "tripgroupmapmodel.h"
 #include "tripgroupmodel.h"
-#include "tripgroupproxymodel.h"
 #include "tripgroupsplitmodel.h"
 #include "unitconversion.h"
 #include "util.h"
@@ -62,6 +62,8 @@
 #if HAVE_MATRIX
 #include "matrix/matrixbeacon.h"
 #include "matrix/matrixroomsmodel.h"
+
+#include <Quotient/keyverificationsession.h>
 #endif
 
 #include "weatherforecastmanager.h"
@@ -83,7 +85,7 @@
 #include <KColorSchemeManager>
 #endif
 
-#include <KLocalizedContext>
+#include <KLocalizedQmlContext>
 #include <KLocalizedString>
 
 #include <KAboutData>
@@ -140,6 +142,13 @@ void registerKItineraryTypes()
     });
 }
 
+void registerQuotientTypes()
+{
+#if HAVE_MATRIX
+    qmlRegisterUncreatableType<Quotient::KeyVerificationSession>("org.kde.quotient", 1, 0, "KeyVerificationSession", {});
+#endif
+}
+
 void registerApplicationTypes()
 {
     qRegisterMetaType<ReservationManager *>();
@@ -147,7 +156,7 @@ void registerApplicationTypes()
     qRegisterMetaType<TripGroupManager *>();
     qRegisterMetaType<WeatherForecast>();
     qRegisterMetaType<Permission::Permission>();
-    qRegisterMetaType<HealthCertificateManager *>();
+    qmlRegisterUncreatableMetaObject(HealthCertificateManager::staticMetaObject, "org.kde.itinerary", 1, 0, "HealthCertificateManager", {});
 
     qmlRegisterUncreatableMetaObject(LocationInformation::staticMetaObject, "org.kde.itinerary", 1, 0, "LocationInformation", {});
     qmlRegisterUncreatableMetaObject(StatisticsItem::staticMetaObject, "org.kde.itinerary", 1, 0, "StatisticsItem", {});
@@ -174,7 +183,6 @@ void registerApplicationTypes()
     qmlRegisterType<TripGroupFilterProxyModel>("org.kde.itinerary", 1, 0, "TripGroupFilterProxyModel");
     qmlRegisterType<TripGroupLocationModel>("org.kde.itinerary", 1, 0, "TripGroupLocationModel");
     qmlRegisterType<TripGroupMapModel>("org.kde.itinerary", 1, 0, "TripGroupMapModel");
-    qmlRegisterType<TripGroupProxyModel>("org.kde.itinerary", 1, 0, "TripGroupProxyModel");
     qmlRegisterType<TripGroupSplitModel>("org.kde.itinerary", 1, 0, "TripGroupSplitModel");
     qmlRegisterType<WeatherForecastModel>("org.kde.itinerary", 1, 0, "WeatherForecastModel");
 #if HAVE_MATRIX
@@ -239,10 +247,6 @@ void registerApplicationSingletons()
     REGISTER_SINGLETON_GADGET_FACTORY(UnitConversion)
     REGISTER_SINGLETON_GADGET_FACTORY(Util)
 
-    qmlRegisterSingletonType("org.kde.itinerary", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
-        return engine->toScriptValue(KAboutData::applicationData());
-    });
-
     qmlRegisterSingletonType<Clipboard>("org.kde.itinerary", 1, 0, "Clipboard", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return new Clipboard;
     });
@@ -304,7 +308,7 @@ int main(int argc, char **argv)
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
     QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
-    KColorSchemeManager colorMgr; // enables automatic dark mode handling
+    KColorSchemeManager::instance(); // enables automatic dark mode handling
 #else
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
     QApplication app(argc, argv); // for native file dialogs
@@ -346,6 +350,8 @@ int main(int argc, char **argv)
     KDBusService service(KDBusService::Unique);
 #endif
 
+    Migrator::run();
+
     IntentHandler intentHandler;
 
     Settings settings;
@@ -448,11 +454,13 @@ int main(int argc, char **argv)
 #endif
     QObject::connect(&intentHandler, &IntentHandler::handleIntent, &appController, &ApplicationController::handleIntent);
     QObject::connect(&importController, &ImportController::infoMessage, &appController, &ApplicationController::infoMessage);
+    QObject::connect(&appController, &ApplicationController::reloadSettings, &settings, &Settings::reloadSettings);
 
     OnlineTicketImporter::setNetworkAccessManagerFactory(namFactory);
 
     registerKPkPassTypes();
     registerKItineraryTypes();
+    registerQuotientTypes();
     registerApplicationTypes();
     registerApplicationSingletons();
 
@@ -474,9 +482,7 @@ int main(int argc, char **argv)
     });
     engine.addImageProvider(QStringLiteral("org.kde.pkpass"), pkPassImageProvider);
 
-    auto l10nContext = new KLocalizedContext(&engine);
-    l10nContext->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
-    engine.rootContext()->setContextObject(l10nContext);
+    KLocalization::setupLocalizedContext(&engine);
     engine.loadFromModule("org.kde.itinerary", "Main");
 
     // Exit on QML load error.
