@@ -78,6 +78,7 @@ bool PublicTransportMatcher::isJourneyForReservation(const QVariant &res, const
     const auto lineData = ReservationHelper::lineNameAndNumber(res);
     return PublicTransportMatcher::isSameMode(res, journey.route().line().mode())
         && KItinerary::SortUtil::startDateTime(res) == journey.scheduledDepartureTime()
+        && KItinerary::SortUtil::endDateTime(res) == journey.scheduledArrivalTime()
         && PublicTransportMatcher::isSameRoute(journey.route(), lineData.first, lineData.second);
 }
 
@@ -122,11 +123,17 @@ KPublicTransport::JourneySection PublicTransportMatcher::subJourneyForReservatio
         return {};
     }
 
+    const auto sameDep = isSameDeparture(KItinerary::LocationUtil::departureLocation(res), res, KItinerary::SortUtil::startDateTime(res), journey.departure());
+    const auto sameArr = isSameArrival(KItinerary::LocationUtil::arrivalLocation(res), res, KItinerary::SortUtil::endDateTime(res), journey.arrival());
+    if (sameDep && sameArr) {
+        return journey;
+    }
+
     KPublicTransport::JourneySection result(journey);
     auto stopovers = result.takeIntermediateStops();
 
     auto it = stopovers.begin();
-    if (!isSameDeparture(KItinerary::LocationUtil::departureLocation(res), res, KItinerary::SortUtil::startDateTime(res), journey.departure())) {
+    if (!sameDep) {
         for (; it != stopovers.end(); ++it) {
             if (isSameDeparture(KItinerary::LocationUtil::departureLocation(res), res, KItinerary::SortUtil::startDateTime(res), *it)) {
                 result.setDeparture(*it);
@@ -145,8 +152,7 @@ KPublicTransport::JourneySection PublicTransportMatcher::subJourneyForReservatio
             break;
         }
     }
-    if (it2 == stopovers.end()
-        && !isSameArrival(KItinerary::LocationUtil::arrivalLocation(res), res, KItinerary::SortUtil::endDateTime(res), journey.arrival())) {
+    if (it2 == stopovers.end() && !sameArr) {
         return {};
     }
 
