@@ -53,6 +53,14 @@ public:
 
     /** Base64 encoding. */
     Q_INVOKABLE [[nodiscard]] static QString toBase64(const QByteArray &data);
+
+    /** Returns and creates cache location path.
+     *  QtCore.StandardPaths returns URLs that QtLocation can't deal with.
+     */
+    Q_INVOKABLE [[nodiscard]] static QString cacheLocation(const QString &relativePath);
+
+    /** Returns a URL slug of the given input string, e.g. for use in filename suggestions. */
+    Q_INVOKABLE [[nodiscard]] static QString slugify(const QString &input);
 };
 
 #endif // UTIL_H
